### pynexrad

This package wraps https://github.com/danielway/nexrad with some additional logic and python bindings.

These bindings are intended to be used by https://github.com/jtfedd/3d-radar and are not very general-purpose.
